@@ -1,4 +1,4 @@
-__version__ = '1.17.9'
+__version__ = '1.17.13'
 import dynaphopy.projection as projection
 import dynaphopy.parameters as parameters
 import dynaphopy.interface.phonopy_link as pho_interface
@@ -86,6 +86,12 @@ class Quasiparticle:
         return self._parameters
 
     def set_NAC(self, NAC):
+        """
+        Turns on or off Non-Analitic corrections
+
+        :param NAC: True or False
+        :return: None
+        """
         self._bands = None
         self.parameters.use_NAC = NAC
 
@@ -185,7 +191,6 @@ class Quasiparticle:
         else:
             raise Exception('Incorrect band ranges format')
 
-
     def get_band_ranges_and_labels(self):
         # return self.parameters.band_ranges
         if self.parameters.band_ranges is None:
@@ -672,13 +677,18 @@ class Quasiparticle:
         plt.legend()
         plt.show()
 
-    def save_vc(self, file_name, atom=0):
+    def save_vc(self, file_name, atom=1):
         print("Saving wave vector projection to file")
-        np.savetxt(file_name, self.get_vc()[:, atom, :].real)
+        if not 0 < atom <= self.get_vc().shape[1]:
+            raise Exception('Atom number {} does not exist in primitive cell'.format(atom))
+        # np.savetxt(file_name, self.get_vc()[:, atom, :].real)
+        np.savetxt(file_name, self.get_vc()[:, atom-1, :], fmt='%+.8e%+.8ej    '*3)
 
     def save_vq(self, file_name):
+        ndim = self.get_vq().shape[1]
         print("Saving phonon projection to file")
-        np.savetxt(file_name, self.get_vq().real)
+        # np.savetxt(file_name, self.get_vq())
+        np.savetxt(file_name, self.get_vq(), fmt='%+.8e%+.8ej    '*ndim)
 
     # Power spectra related methods
     def select_power_spectra_algorithm(self, algorithm):
@@ -841,8 +851,9 @@ class Quasiparticle:
         return self._power_spectrum_partials
 
     def phonon_width_scan_analysis(self):
+        from dynaphopy.power_spectrum import mem_coefficient_scan_analysis
         print("Phonon coefficient scan analysis(Maximum entropy method/Symmetric Lorentzian fit only)")
-        power_spectrum.mem_coefficient_scan_analysis(self.get_vq(), self.dynamic, self.parameters)
+        mem_coefficient_scan_analysis(self.get_vq(), self.dynamic, self.parameters)
 
     def phonon_individual_analysis(self):
         print("Peak analysis analysis")
@@ -1113,7 +1124,8 @@ class Quasiparticle:
 
             for i, reduced_q_vector in enumerate(com_points):
 
-                print("\nQ-point: {0} / {1}      {2}".format(i + 1, len(com_points), reduced_q_vector))
+                print("\nQ-point: {0} / {1} ".format(i + 1, len(com_points)) +
+                      "    [{:8.5f} {:8.5f} {:8.5f} ]".format(*reduced_q_vector))
 
                 self.set_reduced_q_vector(reduced_q_vector)
                 eigenvectors.append(self.get_eigenvectors())
