@@ -1,5 +1,3 @@
-#!/usr/bin/env python -i
-
 import dynaphopy.dynamics as dyn
 import numpy as np
 from dynaphopy.power_spectrum import _progress_bar
@@ -60,6 +58,17 @@ def generate_lammps_trajectory(structure,
     # print ('thermo', lmp.get_thermo('1'))
 
     try:
+        xlo =lmp.extract_global("boxxlo")
+        xhi =lmp.extract_global("boxxhi")
+        ylo =lmp.extract_global("boxylo")
+        yhi =lmp.extract_global("boxyhi")
+        zlo =lmp.extract_global("boxzlo")
+        zhi =lmp.extract_global("boxzhi")
+        xy =lmp.extract_global("xy")
+        yz =lmp.extract_global("yz")
+        xz =lmp.extract_global("xz")
+
+    except TypeError:
         xlo =lmp.extract_global("boxxlo", 1)
         xhi =lmp.extract_global("boxxhi", 1)
         ylo =lmp.extract_global("boxylo", 1)
